% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/paws.R
\name{s3}
\alias{s3}
\title{Amazon Simple Storage Service}
\usage{
s3(config = list())
}
\arguments{
\item{config}{Optional configuration of credentials, endpoint, and/or region.}
}
\description{
Amazon Simple Storage Service
}
\section{Service syntax}{
\preformatted{svc <- s3(
  config = list(
    credentials = list(
      creds = list(
        access_key_id = "string",
        secret_access_key = "string",
        session_token = "string"
      ),
      profile = "string"
    ),
    endpoint = "string",
    region = "string"
  )
)
}
}

\section{Operations}{

\tabular{ll}{
\link[=s3_abort_multipart_upload]{abort_multipart_upload} \tab Aborts a multipart upload \cr
\link[=s3_complete_multipart_upload]{complete_multipart_upload} \tab Completes a multipart upload by assembling previously uploaded parts \cr
\link[=s3_copy_object]{copy_object} \tab Creates a copy of an object that is already stored in Amazon S3 \cr
\link[=s3_create_bucket]{create_bucket} \tab Creates a new bucket \cr
\link[=s3_create_multipart_upload]{create_multipart_upload} \tab Initiates a multipart upload and returns an upload ID \cr
\link[=s3_delete_bucket]{delete_bucket} \tab Deletes the bucket \cr
\link[=s3_delete_bucket_analytics_configuration]{delete_bucket_analytics_configuration} \tab Deletes an analytics configuration for the bucket (specified by the analytics configuration ID) \cr
\link[=s3_delete_bucket_cors]{delete_bucket_cors} \tab Deletes the CORS configuration information set for the bucket \cr
\link[=s3_delete_bucket_encryption]{delete_bucket_encryption} \tab Deletes the server-side encryption configuration from the bucket \cr
\link[=s3_delete_bucket_inventory_configuration]{delete_bucket_inventory_configuration} \tab Deletes an inventory configuration (identified by the inventory ID) from the bucket \cr
\link[=s3_delete_bucket_lifecycle]{delete_bucket_lifecycle} \tab Deletes the lifecycle configuration from the bucket \cr
\link[=s3_delete_bucket_metrics_configuration]{delete_bucket_metrics_configuration} \tab Deletes a metrics configuration (specified by the metrics configuration ID) from the bucket \cr
\link[=s3_delete_bucket_policy]{delete_bucket_policy} \tab Deletes the policy from the bucket \cr
\link[=s3_delete_bucket_replication]{delete_bucket_replication} \tab Deletes the replication configuration from the bucket \cr
\link[=s3_delete_bucket_tagging]{delete_bucket_tagging} \tab Deletes the tags from the bucket \cr
\link[=s3_delete_bucket_website]{delete_bucket_website} \tab This operation removes the website configuration from the bucket \cr
\link[=s3_delete_object]{delete_object} \tab Removes the null version (if there is one) of an object and inserts a delete marker, which becomes the latest version of the object\cr
\link[=s3_delete_object_tagging]{delete_object_tagging} \tab Removes the tag-set from an existing object \cr
\link[=s3_delete_objects]{delete_objects} \tab This operation enables you to delete multiple objects from a bucket using a single HTTP request \cr
\link[=s3_delete_public_access_block]{delete_public_access_block} \tab Removes the PublicAccessBlock configuration from an Amazon S3 bucket \cr
\link[=s3_get_bucket_accelerate_configuration]{get_bucket_accelerate_configuration} \tab Returns the accelerate configuration of a bucket \cr
\link[=s3_get_bucket_acl]{get_bucket_acl} \tab Gets the access control policy for the bucket \cr
\link[=s3_get_bucket_analytics_configuration]{get_bucket_analytics_configuration} \tab Gets an analytics configuration for the bucket (specified by the analytics configuration ID) \cr
\link[=s3_get_bucket_cors]{get_bucket_cors} \tab Returns the CORS configuration for the bucket \cr
\link[=s3_get_bucket_encryption]{get_bucket_encryption} \tab Returns the server-side encryption configuration of a bucket \cr
\link[=s3_get_bucket_inventory_configuration]{get_bucket_inventory_configuration} \tab Returns an inventory configuration (identified by the inventory ID) from the bucket \cr
\link[=s3_get_bucket_lifecycle]{get_bucket_lifecycle} \tab No longer used, see the GetBucketLifecycleConfiguration operation \cr
\link[=s3_get_bucket_lifecycle_configuration]{get_bucket_lifecycle_configuration} \tab Returns the lifecycle configuration information set on the bucket \cr
\link[=s3_get_bucket_location]{get_bucket_location} \tab Returns the region the bucket resides in \cr
\link[=s3_get_bucket_logging]{get_bucket_logging} \tab Returns the logging status of a bucket and the permissions users have to view and modify that status \cr
\link[=s3_get_bucket_metrics_configuration]{get_bucket_metrics_configuration} \tab Gets a metrics configuration (specified by the metrics configuration ID) from the bucket \cr
\link[=s3_get_bucket_notification]{get_bucket_notification} \tab No longer used, see the GetBucketNotificationConfiguration operation \cr
\link[=s3_get_bucket_notification_configuration]{get_bucket_notification_configuration} \tab Returns the notification configuration of a bucket \cr
\link[=s3_get_bucket_policy]{get_bucket_policy} \tab Returns the policy of a specified bucket \cr
\link[=s3_get_bucket_policy_status]{get_bucket_policy_status} \tab Retrieves the policy status for an Amazon S3 bucket, indicating whether the bucket is public \cr
\link[=s3_get_bucket_replication]{get_bucket_replication} \tab Returns the replication configuration of a bucket \cr
\link[=s3_get_bucket_request_payment]{get_bucket_request_payment} \tab Returns the request payment configuration of a bucket \cr
\link[=s3_get_bucket_tagging]{get_bucket_tagging} \tab Returns the tag set associated with the bucket \cr
\link[=s3_get_bucket_versioning]{get_bucket_versioning} \tab Returns the versioning state of a bucket \cr
\link[=s3_get_bucket_website]{get_bucket_website} \tab Returns the website configuration for a bucket \cr
\link[=s3_get_object]{get_object} \tab Retrieves objects from Amazon S3 \cr
\link[=s3_get_object_acl]{get_object_acl} \tab Returns the access control list (ACL) of an object \cr
\link[=s3_get_object_legal_hold]{get_object_legal_hold} \tab Gets an object's current Legal Hold status \cr
\link[=s3_get_object_lock_configuration]{get_object_lock_configuration} \tab Gets the object lock configuration for a bucket \cr
\link[=s3_get_object_retention]{get_object_retention} \tab Retrieves an object's retention settings \cr
\link[=s3_get_object_tagging]{get_object_tagging} \tab Returns the tag-set of an object \cr
\link[=s3_get_object_torrent]{get_object_torrent} \tab Return torrent files from a bucket \cr
\link[=s3_get_public_access_block]{get_public_access_block} \tab Retrieves the PublicAccessBlock configuration for an Amazon S3 bucket \cr
\link[=s3_head_bucket]{head_bucket} \tab This operation is useful to determine if a bucket exists and you have permission to access it \cr
\link[=s3_head_object]{head_object} \tab The HEAD operation retrieves metadata from an object without returning the object itself \cr
\link[=s3_list_bucket_analytics_configurations]{list_bucket_analytics_configurations} \tab Lists the analytics configurations for the bucket \cr
\link[=s3_list_bucket_inventory_configurations]{list_bucket_inventory_configurations} \tab Returns a list of inventory configurations for the bucket \cr
\link[=s3_list_bucket_metrics_configurations]{list_bucket_metrics_configurations} \tab Lists the metrics configurations for the bucket \cr
\link[=s3_list_buckets]{list_buckets} \tab Returns a list of all buckets owned by the authenticated sender of the request \cr
\link[=s3_list_multipart_uploads]{list_multipart_uploads} \tab This operation lists in-progress multipart uploads \cr
\link[=s3_list_object_versions]{list_object_versions} \tab Returns metadata about all of the versions of objects in a bucket \cr
\link[=s3_list_objects]{list_objects} \tab Returns some or all (up to 1000) of the objects in a bucket \cr
\link[=s3_list_objects_v2]{list_objects_v2} \tab Returns some or all (up to 1000) of the objects in a bucket \cr
\link[=s3_list_parts]{list_parts} \tab Lists the parts that have been uploaded for a specific multipart upload \cr
\link[=s3_put_bucket_accelerate_configuration]{put_bucket_accelerate_configuration} \tab Sets the accelerate configuration of an existing bucket \cr
\link[=s3_put_bucket_acl]{put_bucket_acl} \tab Sets the permissions on a bucket using access control lists (ACL) \cr
\link[=s3_put_bucket_analytics_configuration]{put_bucket_analytics_configuration} \tab Sets an analytics configuration for the bucket (specified by the analytics configuration ID) \cr
\link[=s3_put_bucket_cors]{put_bucket_cors} \tab Sets the CORS configuration for a bucket \cr
\link[=s3_put_bucket_encryption]{put_bucket_encryption} \tab Creates a new server-side encryption configuration (or replaces an existing one, if present) \cr
\link[=s3_put_bucket_inventory_configuration]{put_bucket_inventory_configuration} \tab Adds an inventory configuration (identified by the inventory ID) from the bucket \cr
\link[=s3_put_bucket_lifecycle]{put_bucket_lifecycle} \tab No longer used, see the PutBucketLifecycleConfiguration operation \cr
\link[=s3_put_bucket_lifecycle_configuration]{put_bucket_lifecycle_configuration} \tab Sets lifecycle configuration for your bucket \cr
\link[=s3_put_bucket_logging]{put_bucket_logging} \tab Set the logging parameters for a bucket and to specify permissions for who can view and modify the logging parameters \cr
\link[=s3_put_bucket_metrics_configuration]{put_bucket_metrics_configuration} \tab Sets a metrics configuration (specified by the metrics configuration ID) for the bucket \cr
\link[=s3_put_bucket_notification]{put_bucket_notification} \tab No longer used, see the PutBucketNotificationConfiguration operation \cr
\link[=s3_put_bucket_notification_configuration]{put_bucket_notification_configuration} \tab Enables notifications of specified events for a bucket \cr
\link[=s3_put_bucket_policy]{put_bucket_policy} \tab Applies an Amazon S3 bucket policy to an Amazon S3 bucket \cr
\link[=s3_put_bucket_replication]{put_bucket_replication} \tab Creates a replication configuration or replaces an existing one \cr
\link[=s3_put_bucket_request_payment]{put_bucket_request_payment} \tab Sets the request payment configuration for a bucket \cr
\link[=s3_put_bucket_tagging]{put_bucket_tagging} \tab Sets the tags for a bucket \cr
\link[=s3_put_bucket_versioning]{put_bucket_versioning} \tab Sets the versioning state of an existing bucket \cr
\link[=s3_put_bucket_website]{put_bucket_website} \tab Set the website configuration for a bucket \cr
\link[=s3_put_object]{put_object} \tab Adds an object to a bucket \cr
\link[=s3_put_object_acl]{put_object_acl} \tab uses the acl subresource to set the access control list (ACL) permissions for an object that already exists in a bucket \cr
\link[=s3_put_object_legal_hold]{put_object_legal_hold} \tab Applies a Legal Hold configuration to the specified object \cr
\link[=s3_put_object_lock_configuration]{put_object_lock_configuration} \tab Places an object lock configuration on the specified bucket \cr
\link[=s3_put_object_retention]{put_object_retention} \tab Places an Object Retention configuration on an object \cr
\link[=s3_put_object_tagging]{put_object_tagging} \tab Sets the supplied tag-set to an object that already exists in a bucket \cr
\link[=s3_put_public_access_block]{put_public_access_block} \tab Creates or modifies the PublicAccessBlock configuration for an Amazon S3 bucket \cr
\link[=s3_restore_object]{restore_object} \tab Restores an archived copy of an object back into Amazon S3 \cr
\link[=s3_select_object_content]{select_object_content} \tab This operation filters the contents of an Amazon S3 object based on a simple Structured Query Language (SQL) statement \cr
\link[=s3_upload_part]{upload_part} \tab Uploads a part in a multipart upload \cr
\link[=s3_upload_part_copy]{upload_part_copy} \tab Uploads a part by copying data from an existing object as data source
}
}

\examples{
# The following example aborts a multipart upload.
\donttest{svc <- s3()
svc$abort_multipart_upload(
  Bucket = "examplebucket",
  Key = "bigobject",
  UploadId = "xadcOB_7YPBOJuoFiQ9cz4P3Pe6FIZwO4f7wN93uHsNBEw97pl5eNwzExg0LAT2dUN91cOmrEQHDsP..."
)}

}
